require "test/unit"
require "OWLScribble"

class OWLScribble_Test < Test::Unit::TestCase
	def setup
	end

	def test1_basic_paragraphs
		unstyled_line = "Hello World!"
		two_lines = "Hello\nWorld!"
		two_para = [
			"Hello World\n\nHow are you?!",
			"Hello World\n\nHow are you?!\n",
			"Hello World\n\nHow are you?!\n\n",
			"Hello World\n\n\nHow are you?!",
			"Hello World\n\n\n\nHow are you?!",
			"\nHello World\n\n\nHow are you?!",
		]

		owl = OWLScribble.new( unstyled_line )
		assert_equal( 1, owl.tags.length )
		assert_equal( :p, owl.tags.first.tag_name )
		
		owl = OWLScribble.new( two_lines )
		assert_equal( 1, owl.tags.length )
		assert_equal( :p, owl.tags.first.tag_name )
		
		two_para.each{ |input|
			owl = OWLScribble.new( input )
			assert_equal( 2, owl.tags.length )
			owl.tags.each{ |tag|
				assert_equal( :p, tag.tag_name, "foo" )
			}
		}		
	end

	def test2_inline_bold
 		input = "Hello **World**"
		output = %r{<p>Hello <b>World</b></p>\s*}
		owl = OWLScribble.new( input )
		assert( output =~ owl.to_xml )

 		input = "The answer is **5 * 9**!"
		output = %r{<p>The answer is <b>5 \* 9</b>!</p>\s*}
		owl = OWLScribble.new( input )
		assert( output =~ owl.to_xml )

		input = "This is **bold1 with **bold2** illegally inside**."
		output = %r{<p>This is <b>bold1 with </b>bold2<b> illegally inside</b>.</p>\s*}
		owl = OWLScribble.new( input )
		assert( output =~ owl.to_xml )		
	end
	
	def test3_links
		input = "GavinKistner is testing OWLScribble's WikiLinkCreation"
		input<< " such as HandleXML or [[27 [FrEaK]s?!]] or [LinkMe Hot Stuff!] or HoundOfTheBaskerville"
		input<< " but not A2B or ~FooBar or ~[[This]]"
		owl = OWLScribble.new( input )
		assert_equal( 7, owl.wiki_links.length )
		page_names = [ 'GavinKistner', 'OWLScribble', 'WikiLinkCreation', 'HandleXML', '27 [FrEaK]s?!', 'LinkMe', 'HoundOfTheBaskerville' ]
		display_names = [ 'Gavin Kistner', 'OWL Scribble', 'Wiki Link Creation', 'Handle XML', '27 [FrEaK]s?!', 'Hot Stuff!', 'Hound of the Baskerville' ]
		owl.wiki_links.each_with_index{ |tag,i|
			assert_equal( page_names[ i ], tag.attributes[ :page ] )
			assert_equal( display_names[ i ], tag.inner_text )
		}
	end
	
	def test4_docs
		input = "== Engineering ==\nHere's the home page from engineering:\n\n##Include(EngineeringHome)##\n"
		owl = OWLScribble.new( input )
		html = owl.to_html
		output1 = %Q{<h2 id="Engineering">Engineering</h2>\n<div class="section">\n<p>Here's the home page from engineering:</p>\n<wiki_command do="Include" param="EngineeringHome"></wiki_command>\n</div>\n}
		output2 = %Q{<h2 id="Engineering">Engineering</h2>\n<div class="section">\n<p>Here's the home page from engineering:</p>\n<wiki_command param="EngineeringHome"do="Include" ></wiki_command>\n</div>\n}
		assert( html == output1 || html == output2 )
	end
	
end